@@ -16,8 +16,8 @@
 use strict;
 use warnings;
 
-use FindBin;
-use lib "$FindBin::Bin/../lib";
+use Cwd qw(abs_path);
+use lib abs_path . "/../lib";
 
 my $prog_name = $0; $prog_name =~ s{^.*[\\/]}{}g;
 
